@@ -120,15 +120,59 @@ GSourceFuncs TargetSource::s_sourceFuncs = {
 BaseBackend::BaseBackend(int hostFD)
 {
     m_wl.display = wl_display_connect_to_fd(hostFD);
+
+    struct wl_registry* registry = wl_display_get_registry(m_wl.display);
+    wl_registry_add_listener(registry, &s_registryListener, this);
+    wl_display_roundtrip(m_wl.display);
+    wl_registry_destroy(registry);
+
+    if (!m_wl.wpeBridge)
+        g_error("Failed to bind wpe_bridge");
+
+    wpe_bridge_add_listener(m_wl.wpeBridge, &s_bridgeListener, this);
+    wpe_bridge_initialize(m_wl.wpeBridge);
+    wl_display_roundtrip(m_wl.display);
 }
 
 BaseBackend::~BaseBackend()
 {
-    if (m_wl.display)
-        wl_display_disconnect(m_wl.display);
-    m_wl.display = nullptr;
+    g_clear_pointer(&m_wl.wpeBridge, wpe_bridge_destroy);
+    g_clear_pointer(&m_wl.display, wl_display_disconnect);
 }
 
+const struct wl_registry_listener BaseBackend::s_registryListener = {
+    // global
+    [](void* data, struct wl_registry* registry, uint32_t name, const char* interface, uint32_t)
+    {
+        auto& backend = *reinterpret_cast<BaseBackend*>(data);
+
+        if (!std::strcmp(interface, "wpe_bridge"))
+            backend.m_wl.wpeBridge = static_cast<struct wpe_bridge*>(wl_registry_bind(registry, name, &wpe_bridge_interface, 1));
+    },
+    // global_remove
+    [](void*, struct wl_registry*, uint32_t) { },
+};
+
+const struct wpe_bridge_listener BaseBackend::s_bridgeListener = {
+    // implementation_info
+    [](void* data, struct wpe_bridge*, uint32_t implementationType)
+    {
+        auto& backend = *reinterpret_cast<BaseBackend*>(data);
+        switch (implementationType) {
+        case WPE_BRIDGE_CLIENT_IMPLEMENTATION_TYPE_WAYLAND:
+            backend.m_type = ClientImplementationType::Wayland;
+            break;
+        case WPE_BRIDGE_CLIENT_IMPLEMENTATION_TYPE_DMABUF_POOL:
+            backend.m_type = ClientImplementationType::DmabufPool;
+            break;
+        default:
+            break;
+        }
+    },
+    // connected
+    [](void* data, struct wpe_bridge*, uint32_t) { },
+};
+
 
 BaseTarget::BaseTarget(int hostFD, Impl& impl)
     : m_impl(impl)
@@ -144,6 +188,7 @@ BaseTarget::~BaseTarget()
     g_clear_pointer(&m_wl.frameCallback, wl_callback_destroy);
     g_clear_pointer(&m_wl.surface, wl_surface_destroy);
 
+    g_clear_pointer(&m_wl.wpeDmabufPoolManager, wpe_dmabuf_pool_manager_destroy);
     g_clear_pointer(&m_wl.wpeBridge, wpe_bridge_destroy);
     g_clear_pointer(&m_wl.compositor, wl_compositor_destroy);
     g_clear_pointer(&m_wl.eventQueue, wl_event_queue_destroy);
@@ -154,25 +199,11 @@ BaseTarget::~BaseTarget()
     }
 }
 
-GSource* ws_polling_source_new(const char* name, struct wl_display* display, struct wl_event_queue* eventQueue)
+void BaseTarget::initialize(BaseBackend& backend)
 {
-    GSource* wlSource = g_source_new(&TargetSource::s_sourceFuncs, sizeof(TargetSource));
-    auto& source = *reinterpret_cast<TargetSource*>(wlSource);
-    source.pfd.fd = wl_display_get_fd(display);
-    source.pfd.events = G_IO_IN | G_IO_ERR | G_IO_HUP;
-    source.pfd.revents = 0;
-    source.display = display;
-    source.queue = eventQueue;
-    source.isReading = false;
+    m_backend = &backend;
+    struct wl_display* display = backend.display();
 
-    g_source_add_poll(wlSource, &source.pfd);
-    g_source_set_name(wlSource, name);
-    g_source_set_can_recurse(wlSource, TRUE);
-    return wlSource;
-}
-
-void BaseTarget::initialize(struct wl_display* display)
-{
     m_wl.eventQueue = wl_display_create_queue(display);
 
     struct wl_registry* registry = wl_display_get_registry(display);
@@ -181,9 +212,17 @@ void BaseTarget::initialize(struct wl_display* display)
     wl_display_roundtrip_queue(display, m_wl.eventQueue);
     wl_registry_destroy(registry);
 
+    if (!m_wl.compositor)
+        g_error("Failed to bind wl_compositor");
+    if (!m_wl.wpeBridge)
+        g_error("Failed to bind wpe_bridge");
+
     m_wl.surface = wl_compositor_create_surface(m_wl.compositor);
     wl_proxy_set_queue(reinterpret_cast<struct wl_proxy*>(m_wl.surface), m_wl.eventQueue);
 
+    m_wl.wpeDmabufPool = wpe_dmabuf_pool_manager_create_pool(m_wl.wpeDmabufPoolManager, m_wl.surface);
+    wl_proxy_set_queue(reinterpret_cast<struct wl_proxy*>(m_wl.wpeDmabufPool), m_wl.eventQueue);
+
     m_glib.wlSource = ws_polling_source_new("WPEBackend-fdo::wayland", display, m_wl.eventQueue);
     g_source_attach(m_glib.wlSource, g_main_context_get_thread_default());
 
@@ -224,6 +263,8 @@ const struct wl_registry_listener BaseTarget::s_registryListener = {
             target.m_wl.compositor = static_cast<struct wl_compositor*>(wl_registry_bind(registry, name, &wl_compositor_interface, 1));
         if (!std::strcmp(interface, "wpe_bridge"))
             target.m_wl.wpeBridge = static_cast<struct wpe_bridge*>(wl_registry_bind(registry, name, &wpe_bridge_interface, 1));
+        if (!std::strcmp(interface, "wpe_dmabuf_pool_manager"))
+            target.m_wl.wpeDmabufPoolManager = static_cast<struct wpe_dmabuf_pool_manager*>(wl_registry_bind(registry, name, &wpe_dmabuf_pool_manager_interface, 1));
     },
     // global_remove
     [](void*, struct wl_registry*, uint32_t) { },
@@ -238,6 +279,8 @@ const struct wl_callback_listener BaseTarget::s_callbackListener = {
 };
 
 const struct wpe_bridge_listener BaseTarget::s_bridgeListener = {
+    // implementation_info
+    [](void*, struct wpe_bridge*, uint32_t) { },
     // connected
     [](void* data, struct wpe_bridge*, uint32_t id)
     {
@@ -245,4 +288,22 @@ const struct wpe_bridge_listener BaseTarget::s_bridgeListener = {
     },
 };
 
+
+GSource* ws_polling_source_new(const char* name, struct wl_display* display, struct wl_event_queue* eventQueue)
+{
+    GSource* wlSource = g_source_new(&TargetSource::s_sourceFuncs, sizeof(TargetSource));
+    auto& source = *reinterpret_cast<TargetSource*>(wlSource);
+    source.pfd.fd = wl_display_get_fd(display);
+    source.pfd.events = G_IO_IN | G_IO_ERR | G_IO_HUP;
+    source.pfd.revents = 0;
+    source.display = display;
+    source.queue = eventQueue;
+    source.isReading = false;
+
+    g_source_add_poll(wlSource, &source.pfd);
+    g_source_set_name(wlSource, name);
+    g_source_set_can_recurse(wlSource, TRUE);
+    return wlSource;
+}
+
 } // namespace WS
