@@ -25,6 +25,7 @@
 
 #pragma once
 
+#include "ws-types.h"
 #include <functional>
 #include <glib.h>
 #include <memory>
@@ -32,18 +33,23 @@
 #include <wayland-server.h>
 
 struct linux_dmabuf_buffer;
+struct wpe_dmabuf_pool_entry;
 struct wpe_video_plane_display_dmabuf_export;
 struct wpe_audio_packet_export;
 
 namespace WS {
 
-struct ExportableClient {
-    virtual ~ExportableClient() = default;
+struct APIClient {
+    virtual ~APIClient() = default;
+
     virtual void exportBufferResource(struct wl_resource*) = 0;
     virtual void exportLinuxDmabuf(const struct linux_dmabuf_buffer *dmabuf_buffer) = 0;
     virtual void exportShmBuffer(struct wl_resource*, struct wl_shm_buffer*) = 0;
     virtual void exportEGLStreamProducer(struct wl_resource*) = 0;
 
+    virtual struct wpe_dmabuf_pool_entry* createDmabufPoolEntry() = 0;
+    virtual void commitDmabufPoolEntry(struct wpe_dmabuf_pool_entry*) = 0;
+
     // Invoked when the association with the surface associated with a given
     // wpe_bridge identifier is no longer valid, typically due to the nested
     // compositor client being disconnected before having the chance to read
@@ -71,7 +77,7 @@ struct Surface {
 
     struct wl_resource* resource;
 
-    ExportableClient* exportableClient { nullptr };
+    APIClient* apiClient { nullptr };
 
     struct wl_resource* bufferResource { nullptr };
     const struct linux_dmabuf_buffer* dmabufBuffer { nullptr };
@@ -114,24 +120,20 @@ class Instance {
 public:
     class Impl {
     public:
-        enum class Type {
-            EGL,
-            EGLStream,
-            SHM,
-        };
-
         Impl() = default;
         virtual ~Impl() = default;
 
         void setInstance(Instance& instance) { m_instance = &instance; }
         struct wl_display* display() { return m_instance->m_display; }
 
-        virtual Type type() const = 0;
+        virtual ImplementationType type() const = 0;
         virtual bool initialized() const = 0;
 
         virtual void surfaceAttach(Surface&, struct wl_resource*) = 0;
         virtual void surfaceCommit(Surface&) = 0;
 
+        virtual struct wpe_dmabuf_pool_entry* createDmabufPoolEntry(Surface&) = 0;
+
     private:
         Instance* m_instance { nullptr };
     };
@@ -147,7 +149,7 @@ public:
 
     void registerSurface(uint32_t, Surface*);
     void unregisterSurface(Surface*);
-    void registerViewBackend(uint32_t, ExportableClient&);
+    void registerViewBackend(uint32_t, APIClient&);
     void unregisterViewBackend(uint32_t);
     void dispatchFrameCallbacks(uint32_t);
 
@@ -181,6 +183,7 @@ private:
     struct wl_display* m_display { nullptr };
     struct wl_global* m_compositor { nullptr };
     struct wl_global* m_wpeBridge { nullptr };
+    struct wl_global* m_wpeDmabufPoolManager { nullptr };
     GSource* m_source { nullptr };
 
     // (bridgeId -> Surface)
